@@ -42,28 +42,7 @@ USE_CERTIFI = str(USE_CERTIFI).lower() in ['true', '1']
 
 # File containing one or more PEM-encoded CA certificates
 # concatenated together.
-CA_CERTS_PATH = [
-    # centos/fedora: openssl
-    '/etc/pki/tls/certs/ca-bundle.crt',
-
-    # debian/ubuntu/arch/gentoo: ca-certificates
-    '/etc/ssl/certs/ca-certificates.crt',
-
-    # freebsd: ca_root_nss
-    '/usr/local/share/certs/ca-root-nss.crt',
-
-    # macports: curl-ca-bundle
-    '/opt/local/share/curl/curl-ca-bundle.crt',
-
-    # homebrew: openssl
-    '/usr/local/etc/openssl/cert.pem',
-
-    # homebrew: curl-ca-bundle (backward compatibility)
-    '/usr/local/opt/curl-ca-bundle/share/ca-bundle.crt',
-
-    # opensuse/sles: openssl
-    '/etc/ssl/certs/YaST-CA.pem',
-]
+CA_CERTS_PATH = None
 
 # Insert certifi CA bundle path to the front of Libcloud CA bundle search
 # path if certifi is available
@@ -76,7 +55,7 @@ else:
 
 if has_certifi and USE_CERTIFI:
     certifi_ca_bundle_path = certifi.where()
-    CA_CERTS_PATH.insert(0, certifi_ca_bundle_path)
+    CA_CERTS_PATH = certifi_ca_bundle_path
 
 # Allow user to explicitly specify which CA bundle to use, using an environment
 # variable
